@@ -21,6 +21,7 @@
 from collections import deque
 import inspect
 import functools
+import operator
 
 from . import invocation
 from . import signature
@@ -30,6 +31,12 @@ from .mock_registry import mock_registry
 
 __all__ = ['mock']
 
+__tracebackhide__ = operator.methodcaller(
+    "errisinstance",
+    invocation.InvocationError
+)
+
+
 
 class _Dummy(object):
     # We spell out `__call__` here for convenience. All other magic methods
@@ -71,7 +78,10 @@ class Mock(object):
         if self.spec is None:
             return None
 
-        return self.spec.__dict__.get(method_name)
+        try:
+            return self.spec.__dict__.get(method_name)
+        except AttributeError:
+            return getattr(self.spec, method_name, None)
 
     def set_method(self, method_name, new_method):
         setattr(self.mocked_obj, method_name, new_method)
@@ -80,9 +90,11 @@ class Mock(object):
 
         def new_mocked_method(*args, **kwargs):
             # we throw away the first argument, if it's either self or cls
-            if (inspect.ismethod(new_mocked_method) or
-                    inspect.isclass(self.mocked_obj) and
-                    not isinstance(new_mocked_method, staticmethod)):
+            if (
+                inspect.ismethod(new_mocked_method)
+                or inspect.isclass(self.mocked_obj)
+                and not isinstance(new_mocked_method, staticmethod)
+            ):
                 args = args[1:]
 
             return remembered_invocation_builder(
@@ -97,15 +109,19 @@ class Mock(object):
             except AttributeError:
                 pass
 
-        if (inspect.ismethod(original_method)):
+        if inspect.ismethod(original_method):
             new_mocked_method = utils.newmethod(
-                new_mocked_method, self.mocked_obj)
+                new_mocked_method, self.mocked_obj
+            )
+
         if isinstance(original_method, staticmethod):
             new_mocked_method = staticmethod(new_mocked_method)
         elif isinstance(original_method, classmethod):
             new_mocked_method = classmethod(new_mocked_method)
-        elif (inspect.isclass(self.mocked_obj) and  # TBC: Inner classes
-                inspect.isclass(original_method)):
+        elif (
+            inspect.isclass(self.mocked_obj)
+            and inspect.isclass(original_method)  # TBC: Inner classes
+        ):
             new_mocked_method = staticmethod(new_mocked_method)
 
         self.set_method(method_name, new_mocked_method)
@@ -140,8 +156,11 @@ class Mock(object):
         # must delete it here.
         # If we mocked an instance, our mocked function will actually hide
         # the one on its class, so we delete as well.
-        if (not original_method or not inspect.isclass(self.mocked_obj) and
-                inspect.ismethod(original_method)):
+        if (
+            not original_method
+            or not inspect.isclass(self.mocked_obj)
+            and inspect.ismethod(original_method)
+        ):
             delattr(self.mocked_obj, method_name)
         else:
             self.set_method(method_name, original_method)
@@ -239,6 +258,10 @@ def mock(config_or_spec=None, spec=None, strict=OMITTED):
 
         def __getattr__(self, method_name):
             if strict:
+                __tracebackhide__ = operator.methodcaller(
+                    "errisinstance", AttributeError
+                )
+
                 raise AttributeError(
                     "'Dummy' has no attribute %r configured" % method_name)
             return functools.partial(
@@ -257,11 +280,11 @@ def mock(config_or_spec=None, spec=None, strict=OMITTED):
     obj = Dummy()
     theMock = Mock(Dummy, strict=strict, spec=spec)
 
-    for n, v in list(config.items()):
+    for n, v in config.items():
         if inspect.isfunction(v):
             invocation.StubbedInvocation(theMock, n)(Ellipsis).thenAnswer(v)
         else:
-            setattr(obj, n, v)
+            setattr(Dummy, n, v)
 
     mock_registry.register(obj, theMock)
     return obj
