@@ -34,9 +34,11 @@ def get_function_host(fn):
     """
 
     obj = None
-    if inspect.ismethod(fn):
+    try:
         name = fn.__name__
         obj = fn.__self__
+    except AttributeError:
+        pass
 
     if obj is None:
         # Due to how python imports work, everything that is global on a module
@@ -71,7 +73,7 @@ def find_invoking_frame_and_try_parse():
     # Actually we just want the first frame in user land; we're open for
     # refactorings here and don't yet decide on which frame exactly we hit
     # that user land.
-    stack = inspect.stack(2)[2:10]
+    stack = inspect.stack(3)[2:10]
     for frame_info in stack:
         # Within `patch` and `spy2` we delegate to `when2` but that's not
         # user land code
